@@ -22,6 +22,7 @@ __all__ = [
 		"py_modules",
 		"entry_points",
 		"__license__",
+		"__author__",
 		"short_desc",
 		"author",
 		"author_email",
@@ -42,7 +43,7 @@ __copyright__ = """
 2019-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-__version__ = "0.3.6"
+__version__ = "0.3.7"
 
 modname = "domdf_python_tools"
 pypi_name = "domdf_python_tools"
@@ -54,7 +55,7 @@ entry_points = {
 
 __license__ = "GNU Lesser General Public License v3 or later (LGPLv3+)"
 
-short_desc = "Helpful functions for Python"
+short_desc = "Helpful functions for Python 🐍 🛠️"
 
 __author__ = author = "Dominic Davis-Foster"
 author_email = "dominic@davis-foster.co.uk"
@@ -69,30 +70,32 @@ project_urls = {
 repo_root = pathlib.Path(__file__).parent
 
 # Get info from files; set: long_description
-long_description = (repo_root / "README.rst").read_text().replace("0.3.6", __version__) + '\n'
-conda_description = """Helpful functions for Python
+long_description = (repo_root / "README.rst").read_text(encoding="utf-8").replace("0.3.7", __version__) + '\n'
+conda_description = """Helpful functions for Python 🐍 🛠️
 
 
 Before installing please ensure you have added the following channels: domdfcoding, conda-forge"""
 __all__.append("conda_description")
 
-install_requires = (repo_root / "requirements.txt").read_text().split('\n')
+install_requires = (repo_root / "requirements.txt").read_text(encoding="utf-8").split('\n')
 extras_require = {'dates': ['pytz>=2019.1'], 'all': ['pytz>=2019.1']}
 
 classifiers = [
 		'Development Status :: 4 - Beta',
 		'Intended Audience :: Developers',
+		'License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)',
 		'Operating System :: OS Independent',
 		'Programming Language :: Python',
 		'Programming Language :: Python :: 3 :: Only',
-		'Topic :: Software Development :: Libraries :: Python Modules',
 		'Programming Language :: Python :: 3.6',
-		'Programming Language :: Python :: Implementation :: CPython',
 		'Programming Language :: Python :: 3.7',
 		'Programming Language :: Python :: 3.8',
+		'Programming Language :: Python :: 3.9',
+		'Programming Language :: Python :: Implementation :: CPython',
 		'Programming Language :: Python :: Implementation :: PyPy',
-		'License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)',
+		'Topic :: Software Development :: Libraries :: Python Modules',
+		'Typing :: Typed',
 
 		]
 
-keywords = ""
+keywords = "utilities"
